@@ -13,7 +13,7 @@
 class KcmDbusInterface : public QObject
 {
     Q_OBJECT
-    Q_CLASSINFO("D-Bus Interface", "org.kde.plasma-remotecontrollers.KCM")
+    Q_CLASSINFO("D-Bus Interface", "org.kde.plasma.remotecontrollers.KCM")
 
 public:
     explicit KcmDbusInterface(QObject *parent = nullptr);
@@ -26,4 +26,4 @@ Q_SIGNALS:
     void evdevKeyPressed(int keyCode);
 };
 
-#endif // KCMDBUSINTERFACE_H
\ No newline at end of file
+#endif // KCMDBUSINTERFACE_H
