@@ -70,8 +70,8 @@ bool EvdevController::addDevice(const Solid::Device &device)
         return false;
     }
 
-    qCInfo(PLASMARC_EVDEV) << "Added evdev device:" << device.displayName();
-    auto evdevDevice = new EvdevDevice(device.udi(), dev);
+    qCInfo(PLASMARC_EVDEV) << "Added evdev device:" << device.udi();
+    auto evdevDevice = new EvdevDevice(device.udi(), dev, this);
     ControllerManager::instance().newDevice(evdevDevice);
 
     auto notifier = new QSocketNotifier(fd, QSocketNotifier::Read, this);
@@ -80,19 +80,35 @@ bool EvdevController::addDevice(const Solid::Device &device)
     return true;
 }
 
-EvdevController &EvdevController::instance()
-{
-    static EvdevController instance;
-    return instance;
-}
-
-EvdevDevice::EvdevDevice(const QString& path, libevdev *device)
+EvdevDevice::EvdevDevice(const QString& path, libevdev *device, EvdevController *controller)
     : Device(DeviceGamepad, QString::fromUtf8(libevdev_get_name(device)), path)
+    , m_controller(controller)
     , m_device(device)
     , m_udi(path)
+    , m_buttons ({
+        { BTN_MODE, { KEY_LEFTMETA } },
+        { BTN_START, { KEY_GAMES } },
+        { BTN_SOUTH, { KEY_ENTER } },
+        { BTN_EAST, { KEY_CANCEL } },
+        { BTN_WEST, { KEY_MENU } },
+        { BTN_TL, { KEY_LEFTSHIFT, KEY_TAB } },
+        { BTN_TR, { KEY_TAB } },
+        { BTN_TL2, { KEY_BACK } },
+        { BTN_TR2, { KEY_FORWARD } },
+        { BTN_DPAD_UP, { KEY_UP } },
+        { BTN_DPAD_DOWN, { KEY_DOWN } },
+        { BTN_DPAD_LEFT, { KEY_LEFT } },
+        { BTN_DPAD_RIGHT, { KEY_RIGHT } }
+    })
 {
     auto notifier = Solid::DeviceNotifier::instance();
     connect(notifier, &Solid::DeviceNotifier::deviceRemoved, this, &EvdevDevice::deviceRemoved);
+
+    QSet<int> keys;
+    for (auto keyCombination : m_buttons) {
+        keys += QSet<int>(keyCombination.cbegin(), keyCombination.cend());
+    }
+    setUsedKeys(keys);
 }
 
 EvdevDevice::~EvdevDevice()
@@ -118,7 +134,7 @@ void EvdevDevice::setKey(int key, bool pressed)
     } else {
         m_pressedKeys.remove(key);
     }
-    EvdevController::instance().m_dbusInterface.emitKeyPress(key);
+    m_controller->m_dbusInterface.emitKeyPress(key);
     ControllerManager::instance().emitKey(key, pressed);
 }
 
@@ -148,26 +164,11 @@ void EvdevDevice::readNow()
 void EvdevDevice::processEvent(struct input_event& ev)
 {
     if (ev.type == EV_KEY) {
-        static const QMap<int, QVector<int>> s_buttons = {
-            { BTN_MODE, { KEY_LEFTMETA } },
-            { BTN_START, { KEY_GAMES } },
-            { BTN_SOUTH, { KEY_ENTER } },
-            { BTN_EAST, { KEY_CANCEL } },
-            { BTN_WEST, { KEY_MENU } },
-            { BTN_TL, { KEY_LEFTSHIFT, KEY_TAB } },
-            { BTN_TR, { KEY_TAB } },
-            { BTN_TL2, { KEY_BACK } },
-            { BTN_TR2, { KEY_FORWARD } },
-            { BTN_DPAD_UP, { KEY_UP } },
-            { BTN_DPAD_DOWN, { KEY_DOWN } },
-            { BTN_DPAD_LEFT, { KEY_LEFT } },
-            { BTN_DPAD_RIGHT, { KEY_RIGHT } }
-        };
-        const auto nativeKeyCodes = s_buttons.value(ev.code);
+        const auto nativeKeyCodes = m_buttons.value(ev.code);
 
         if (!nativeKeyCodes.isEmpty()) {
             for (auto code : nativeKeyCodes) {
-                EvdevController::instance().m_dbusInterface.emitKeyPress(ev.code);
+                m_controller->m_dbusInterface.emitKeyPress(ev.code);
                 ControllerManager::instance().emitKey(code, ev.value);
             }
             return;
